package com.pj.project.tb_business;

import java.util.List;

import com.pj.utils.so.SoMap;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.bind.annotation.*;

import com.pj.utils.sg.*;
import com.pj.project4sp.SP;

import com.pj.current.satoken.StpUserUtil;
import cn.dev33.satoken.annotation.SaCheckPermission;


/**
 * Controller: tb_business -- 入境登记
 * @author qzy 
 */
@RestController
@RequestMapping("/TbBusiness/")
public class TbBusinessController {

	/** 底层 Service 对象 */
	@Autowired
	TbBusinessService tbBusinessService;

	/** 增 */  
	@RequestMapping("add")
	@SaCheckPermission(TbBusiness.PERMISSION_CODE)
	@Transactional(rollbackFor = Exception.class)
	public AjaxJson add(TbBusiness t){
		tbBusinessService.add(t);
		t = tbBusinessService.getById(SP.publicMapper.getPrimarykey());
		return AjaxJson.getSuccessData(t);
	}

	/** 删 */  
	@RequestMapping("delete")
	@SaCheckPermission(TbBusiness.PERMISSION_CODE)
	public AjaxJson delete(Long id){
		tbBusinessService.removeById(id);
		return AjaxJson.getSuccess();
	}
	
	/** 删 - 根据id列表 */  
	@RequestMapping("deleteByIds")
	@SaCheckPermission(TbBusiness.PERMISSION_CODE)
	public AjaxJson deleteByIds(){
		List<Long> ids = SoMap.getRequestSoMap().getListByComma("ids", long.class);
		int line = SP.publicMapper.deleteByIds(TbBusiness.TABLE_NAME, ids);
		return AjaxJson.getByLine(line);
	}
	
	/** 改 */  
	@RequestMapping("update")
	@SaCheckPermission(TbBusiness.PERMISSION_CODE)
	public AjaxJson update(TbBusiness t){
		tbBusinessService.updateById(t);
		return AjaxJson.getSuccess();
	}

	/** 查 - 根据id */  
	@RequestMapping("getById")
	public AjaxJson getById(Long id){
		TbBusiness t = tbBusinessService.getById(id);
		return AjaxJson.getSuccessData(t);
	}

	/** 查集合 - 根据条件（参数为空时代表忽略指定条件） */  
	@RequestMapping("getList")
	public AjaxJson getList() { 
		SoMap so = SoMap.getRequestSoMap();
		List<TbBusiness> list = tbBusinessService.getList(so.startPage());
		return AjaxJson.getPageData(so.getDataCount(), list);
	}
	
	
	
	
	// ------------------------- 前端接口 -------------------------
	
	
	/** 改 - 不传不改 [G] */
	@RequestMapping("updateByNotNull")
	public AjaxJson updateByNotNull(Long id){
		AjaxError.throwBy(true, "如需正常调用此接口，请删除此行代码");
		// 鉴别身份，是否为数据创建者 
		long userId = SP.publicMapper.getColumnByIdToLong(TbBusiness.TABLE_NAME, "user_id", id);
		AjaxError.throwBy(userId != StpUserUtil.getLoginIdAsLong(), "此数据您无权限修改");
		// 开始修改 (请只保留需要修改的字段)
		SoMap so = SoMap.getRequestSoMap();
		so.clearNotIn("id", "customerId", "customerName", "no", "cardNo", "cardSize", "netWeight", "goodsName", "goodsCode", "driverName", "driverId", "driverPhone", "driverIdCard", "payTicket", "expectInDay", "realInDay", "realInTime", "payStatus", "payTime", "payType", "outDayTime", "partMoney", "partTime").clearNull().humpToLineCase();	
		int line = SP.publicMapper.updateBySoMapById(TbBusiness.TABLE_NAME, so, id);
		return AjaxJson.getByLine(line);
	}
	
	
	
	
	
	

}
